"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateAction = void 0;
const colors_1 = __importDefault(require("colors"));
const fs_1 = __importDefault(require("fs"));
const commander_1 = require("commander");
const module_1 = require("../language-server/generated/module");
const node_1 = require("langium/node");
const minilogo_module_1 = require("../language-server/minilogo-module");
const cli_util_1 = require("./cli-util");
const generator_1 = require("../generator/generator");
const path_1 = __importDefault(require("path"));
const langium_1 = require("langium");
const generateAction = (fileName, opts) => __awaiter(void 0, void 0, void 0, function* () {
    const services = (0, minilogo_module_1.createMiniLogoServices)(node_1.NodeFileSystem).MiniLogo;
    const model = yield (0, cli_util_1.extractAstNode)(fileName, services);
    const generatedJS = getCmdStackString(model);
    const data = (0, cli_util_1.extractDestinationAndName)(fileName, opts.destination);
    const dest = path_1.default.join(data.destination, data.name);
    const generatedFileJSPath = path_1.default.join(dest, 'mini-logo.js');
    const generatedFileHTMLPath = path_1.default.join(dest, 'index.html');
    if (!fs_1.default.existsSync(dest)) {
        fs_1.default.mkdirSync(dest, { recursive: true });
    }
    // read mini-logo, and add generated JS to it
    const fileContents = fs_1.default.readFileSync(fileName).toString('utf-8').replaceAll(/`/g, '\\`');
    const baseJsContent = fs_1.default.readFileSync('./src/static/setup.js');
    const programText = `\n\nconst LOGO_PROGRAM_TEXT = \`${fileContents}\`;`;
    fs_1.default.writeFileSync(generatedFileJSPath, baseJsContent + '\n\n' + generatedJS + '\n\n' + programText);
    fs_1.default.writeFileSync(generatedFileHTMLPath, fs_1.default.readFileSync('./src/static/index.html'));
    console.log(colors_1.default.green(`HTML/Javascript code generated successfully: ${generatedFileHTMLPath}`));
});
exports.generateAction = generateAction;
/**
 * Gets the command stack as a string
 * @param model Model to extract command stack from
 * @returns String to add to JS
 */
function getCmdStackString(model) {
    const generatedCmds = (0, generator_1.generateMiniLogoCmds)(model);
    // build output JS so something draws to the canvas on load, quickly
    const fileNodeJS = new langium_1.CompositeGeneratorNode();
    fileNodeJS.append("// Generated MiniLogo Commands", langium_1.NL, "MINI_LOGO_COMMANDS = [", langium_1.NL);
    fileNodeJS.append();
    // add cmds
    if (generatedCmds !== undefined) {
        fileNodeJS.indent(i => {
            generatedCmds.forEach(cmd => {
                i.append(JSON.stringify(cmd), ',', langium_1.NL);
            });
        });
    }
    // cap off
    fileNodeJS.append("];", langium_1.NL);
    return (0, langium_1.toString)(fileNodeJS);
}
function default_1() {
    const program = new commander_1.Command();
    program.version(require('../../package.json').version);
    const fileExtensions = module_1.MiniLogoLanguageMetaData.fileExtensions.join(', ');
    program
        .command('generate')
        .argument('<file>', `source file (possible file extensions: ${fileExtensions})`)
        .option('-d, --destination <dir>', 'destination directory of generating')
        .description('generates an HTML page with JavaScript code that draws on a canvas')
        .action(exports.generateAction);
    program.parse(process.argv);
}
exports.default = default_1;
//# sourceMappingURL=index.js.map