"use strict";
/******************************************************************************
 * Copyright 2022 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const langium_1 = require("langium");
const browser_1 = require("vscode-languageserver/browser");
const minilogo_module_1 = require("./minilogo-module");
const minilogo_actions_1 = require("./minilogo-actions");
const generator_1 = require("../generator/generator");
/* browser specific setup code */
const messageReader = new browser_1.BrowserMessageReader(self);
const messageWriter = new browser_1.BrowserMessageWriter(self);
const connection = (0, browser_1.createConnection)(messageReader, messageWriter);
// Inject the shared services and language-specific services
const { shared, MiniLogo } = (0, minilogo_module_1.createMiniLogoServices)(Object.assign({ connection }, langium_1.EmptyFileSystem));
// Start the language server with the shared services
(0, langium_1.startLanguageServer)(shared);
const documentChangeNotification = new browser_1.NotificationType('browser/DocumentChange');
const jsonSerializer = MiniLogo.serializer.JsonSerializer;
shared.workspace.DocumentBuilder.onBuildPhase(langium_1.DocumentState.Validated, documents => {
    var _a;
    for (const document of documents) {
        const module = document.parseResult.value;
        let json = [];
        if (document.diagnostics === undefined || document.diagnostics.filter((i) => i.severity === 1).length === 0) {
            json = (0, minilogo_actions_1.getCommands)((0, generator_1.generateMiniLogoCmds)(module));
        }
        module.$commands = json;
        connection.sendNotification(documentChangeNotification, {
            uri: document.uri.toString(),
            content: jsonSerializer.serialize(module, { sourceText: true, textRegions: true }),
            diagnostics: (_a = document.diagnostics) !== null && _a !== void 0 ? _a : []
        });
    }
});
//# sourceMappingURL=main-browser.js.map