"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMiniLogoServices = exports.MiniLogoModule = void 0;
const langium_1 = require("langium");
const web_1 = require("../web");
const module_1 = require("./generated/module");
const minilogo_validator_1 = require("./minilogo-validator");
/**
 * Dependency injection module that overrides Langium default services and contributes the
 * declared custom services. The Langium defaults can be partially specified to override only
 * selected services, while the custom services must be fully specified.
 */
exports.MiniLogoModule = {
    validation: {
        ValidationRegistry: (services) => new minilogo_validator_1.MiniLogoValidationRegistry(services),
        MiniLogoValidator: () => new minilogo_validator_1.MiniLogoValidator()
    },
};
class MiniLogoCommandHandler extends langium_1.AbstractExecuteCommandHandler {
    registerCommands(acceptor) {
        acceptor('parseAndGenerate', args => {
            // invoke generator on this data, and return response
            return (0, web_1.parseAndGenerate)(args[0]);
        });
    }
}
/**
 * Create the full set of services required by Langium.
 *
 * First inject the shared services by merging two modules:
 *  - Langium default shared services
 *  - Services generated by langium-cli
 *
 * Then inject the language-specific services by merging three modules:
 *  - Langium default language-specific services
 *  - Services generated by langium-cli
 *  - Services specified in this file
 *
 * @param context Optional module context with the LSP connection
 * @returns An object wrapping the shared services and the language-specific services
 */
function createMiniLogoServices(context) {
    const shared = (0, langium_1.inject)((0, langium_1.createDefaultSharedModule)(context), module_1.MiniLogoGeneratedSharedModule);
    const MiniLogo = (0, langium_1.inject)((0, langium_1.createDefaultModule)({ shared }), module_1.MiniLogoGeneratedModule, exports.MiniLogoModule);
    shared.lsp.ExecuteCommandHandler = new MiniLogoCommandHandler();
    shared.ServiceRegistry.register(MiniLogo);
    return { shared, MiniLogo };
}
exports.createMiniLogoServices = createMiniLogoServices;
//# sourceMappingURL=minilogo-module.js.map