"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MiniLogoValidator = exports.MiniLogoValidationRegistry = void 0;
const langium_1 = require("langium");
const ast_1 = require("./generated/ast");
/**
 * Registry for validation checks.
 */
class MiniLogoValidationRegistry extends langium_1.ValidationRegistry {
    constructor(services) {
        super(services);
        const validator = services.validation.MiniLogoValidator;
        const checks = {
            Model: validator.checkUniqueDefs,
            Def: validator.checkUniqueParams
        };
        this.register(checks, validator);
    }
}
exports.MiniLogoValidationRegistry = MiniLogoValidationRegistry;
class MiniLogoValidator {
    checkUniqueDefs(model, accept) {
        if (!(0, ast_1.isModel)(model)) {
            throw new Error('Retrieve a non-model in validation');
        }
        const reported = new Set();
        model.defs.forEach(d => {
            if (reported.has(d.name)) {
                accept('error', `Def has non-unique name '${d.name}'.`, { node: d, property: 'name' });
            }
            reported.add(d.name);
        });
    }
    checkUniqueParams(def, accept) {
        if (!(0, ast_1.isDef)(def)) {
            throw new Error('Retrieve a non-def in validation');
        }
        const reported = new Set();
        def.params.forEach(p => {
            if (reported.has(p.name)) {
                accept('error', `Param ${p.name} is non-unique for Def '${def.name}'`, { node: p, property: 'name' });
            }
            reported.add(p.name);
        });
    }
}
exports.MiniLogoValidator = MiniLogoValidator;
//# sourceMappingURL=minilogo-validator.js.map