"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseAndGenerate = void 0;
const minilogo_module_1 = require("../language-server/minilogo-module");
const generator_1 = require("../generator/generator");
const langium_1 = require("langium");
const vscode_uri_1 = require("vscode-uri");
/**
 * Parses a MiniLogo program & generates output as a list of Objects
 * @param miniLogoProgram MiniLogo program to parse
 * @returns Generated output from this MiniLogo program
 */
function parseAndGenerate(miniLogoProgram) {
    return __awaiter(this, void 0, void 0, function* () {
        const services = (0, minilogo_module_1.createMiniLogoServices)(langium_1.EmptyFileSystem).MiniLogo;
        const model = yield extractAstNodeFromString(miniLogoProgram, services);
        // generate mini logo drawing commands from the model
        const cmds = (0, generator_1.generateMiniLogoCmds)(model);
        return Promise.resolve(cmds);
    });
}
exports.parseAndGenerate = parseAndGenerate;
/**
 * Extracts an AST node from a virtual document, represented as a string
 * @param content Content to create virtual document from
 * @param services For constructing & building a virtual document
 * @returns A promise for the parsed result of the document
 */
function extractAstNodeFromString(content, services) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const doc = services.shared.workspace.LangiumDocumentFactory.fromString(content, vscode_uri_1.URI.parse('memory://minilogo.document'));
        yield services.shared.workspace.DocumentBuilder.build([doc], { validationChecks: 'all' });
        return (_a = doc.parseResult) === null || _a === void 0 ? void 0 : _a.value;
    });
}
//# sourceMappingURL=index.js.map